# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: devices.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'devices.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rdevices.proto\x12\x07\x64\x65vices\"\xf4\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12%\n\x06status\x18\x04 \x01(\x0e\x32\x15.devices.DeviceStatus\x12\x14\n\x0clast_seen_at\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\x12$\n\x07sensors\x18\x08 \x03(\x0b\x32\x13.devices.SensorInfo\x12(\n\tactuators\x18\t \x03(\x0b\x32\x15.devices.ActuatorInfo\"\x7f\n\rDeviceSummary\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12%\n\x06status\x18\x04 \x01(\x0e\x32\x15.devices.DeviceStatus\x12\x14\n\x0clast_seen_at\x18\x05 \x01(\t\"F\n\x13\x43reateDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"8\n\x14\x43reateDeviceResponse\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"H\n\x10GetDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\"8\n\x11GetDeviceResponse\x12#\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x13.devices.DeviceInfo\"W\n\x12ListDevicesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x10\n\x08per_page\x18\x04 \x01(\x05\"M\n\x13ListDevicesResponse\x12\'\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x16.devices.DeviceSummary\x12\r\n\x05total\x18\x02 \x01(\x05\"Y\n\x13UpdateDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\")\n\x14UpdateDeviceResponse\x12\x11\n\tdevice_id\x18\x01 \x01(\t\"K\n\x13\x44\x65leteDeviceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\"\'\n\x14\x44\x65leteDeviceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"T\n\x1cRegenerateDeviceTokenRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\".\n\x1dRegenerateDeviceTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"\x9c\x01\n\nSensorInfo\x12\x11\n\tsensor_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12&\n\nvalue_type\x18\x05 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\"\xb5\x01\n\x13\x43reateSensorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12&\n\nvalue_type\x18\x06 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x07 \x01(\t\x12\x11\n\tprecision\x18\x08 \x01(\x05\")\n\x14\x43reateSensorResponse\x12\x11\n\tsensor_id\x18\x01 \x01(\t\"J\n\x12ListSensorsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\";\n\x13ListSensorsResponse\x12$\n\x07sensors\x18\x01 \x03(\x0b\x32\x13.devices.SensorInfo\"\x93\x01\n\x13UpdateSensorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\")\n\x14UpdateSensorResponse\x12\x11\n\tsensor_id\x18\x01 \x01(\t\"^\n\x13\x44\x65leteSensorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\"\'\n\x14\x44\x65leteSensorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x9b\x01\n\rThresholdInfo\x12\x14\n\x0cthreshold_id\x18\x01 \x01(\t\x12\x11\n\tsensor_id\x18\x02 \x01(\t\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.devices.ThresholdType\x12\r\n\x05value\x18\x04 \x01(\x01\x12,\n\x08severity\x18\x05 \x01(\x0e\x32\x1a.devices.ThresholdSeverity\"\xc1\x01\n\x13SetThresholdRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\x12$\n\x04type\x18\x05 \x01(\x0e\x32\x16.devices.ThresholdType\x12\r\n\x05value\x18\x06 \x01(\x01\x12,\n\x08severity\x18\x07 \x01(\x0e\x32\x1a.devices.ThresholdSeverity\",\n\x14SetThresholdResponse\x12\x14\n\x0cthreshold_id\x18\x01 \x01(\t\"`\n\x15ListThresholdsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\"D\n\x16ListThresholdsResponse\x12*\n\nthresholds\x18\x01 \x03(\x0b\x32\x16.devices.ThresholdInfo\"w\n\x16\x44\x65leteThresholdRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x11\n\tsensor_id\x18\x04 \x01(\t\x12\x14\n\x0cthreshold_id\x18\x05 \x01(\t\"*\n\x17\x44\x65leteThresholdResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"/\n\x1aGetSensorThresholdsRequest\x12\x11\n\tsensor_id\x18\x01 \x01(\t\"I\n\x1bGetSensorThresholdsResponse\x12*\n\nthresholds\x18\x01 \x03(\x0b\x32\x16.devices.ThresholdInfo\"\xea\x01\n\x0c\x41\x63tuatorInfo\x12\x13\n\x0b\x61\x63tuator_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12&\n\nvalue_type\x18\x05 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\x12\x11\n\tmin_value\x18\x08 \x01(\x01\x12\x11\n\tmax_value\x18\t \x01(\x01\x12\x0c\n\x04step\x18\n \x01(\x01\x12\x14\n\x0c\x65num_options\x18\x0b \x03(\t\"\x81\x02\n\x15\x43reateActuatorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12&\n\nvalue_type\x18\x06 \x01(\x0e\x32\x12.devices.ValueType\x12\x12\n\nunit_label\x18\x07 \x01(\t\x12\x11\n\tprecision\x18\x08 \x01(\x05\x12\x11\n\tmin_value\x18\t \x01(\x01\x12\x11\n\tmax_value\x18\n \x01(\x01\x12\x0c\n\x04step\x18\x0b \x01(\x01\x12\x14\n\x0c\x65num_options\x18\x0c \x03(\t\"-\n\x16\x43reateActuatorResponse\x12\x13\n\x0b\x61\x63tuator_id\x18\x01 \x01(\t\"L\n\x14ListActuatorsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\"A\n\x15ListActuatorsResponse\x12(\n\tactuators\x18\x01 \x03(\x0b\x32\x15.devices.ActuatorInfo\"\xe1\x01\n\x15UpdateActuatorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x63tuator_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\nunit_label\x18\x06 \x01(\t\x12\x11\n\tprecision\x18\x07 \x01(\x05\x12\x11\n\tmin_value\x18\x08 \x01(\x01\x12\x11\n\tmax_value\x18\t \x01(\x01\x12\x0c\n\x04step\x18\n \x01(\x01\x12\x14\n\x0c\x65num_options\x18\x0b \x03(\t\"-\n\x16UpdateActuatorResponse\x12\x13\n\x0b\x61\x63tuator_id\x18\x01 \x01(\t\"b\n\x15\x44\x65leteActuatorRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x63tuator_id\x18\x04 \x01(\t\")\n\x16\x44\x65leteActuatorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"o\n\x12SendCommandRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63tuator_key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"&\n\x13SendCommandResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"?\n\x19\x41uthenticateDeviceRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"+\n\x1a\x41uthenticateDeviceResponse\x12\r\n\x05\x61llow\x18\x01 \x01(\x08\"H\n\x15\x43heckDeviceAclRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\"\'\n\x16\x43heckDeviceAclResponse\x12\r\n\x05\x61llow\x18\x01 \x01(\x08\"1\n\x1eGenerateMqttCredentialsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"Y\n\x1fGenerateMqttCredentialsResponse\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x12\n\nexpires_at\x18\x03 \x01(\x03\"U\n\x19UpdateDeviceStatusRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12%\n\x06status\x18\x02 \x01(\x0e\x32\x15.devices.DeviceStatus\"-\n\x1aUpdateDeviceStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"/\n\x1b\x44\x65leteDevicesByPlaceRequest\x12\x10\n\x08place_id\x18\x01 \x01(\t\"Z\n\x1c\x44\x65leteDevicesByPlaceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rdeleted_count\x18\x02 \x01(\x05\x12\x12\n\ndevice_ids\x18\x03 \x03(\t\"\x19\n\x17GetAllThresholdsRequest\"\x87\x01\n\x14SensorWithThresholds\x12\x11\n\tsensor_id\x18\x01 \x01(\t\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x10\n\x08place_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12*\n\nthresholds\x18\x05 \x03(\x0b\x32\x16.devices.ThresholdInfo\"J\n\x18GetAllThresholdsResponse\x12.\n\x07sensors\x18\x01 \x03(\x0b\x32\x1d.devices.SensorWithThresholds\"4\n InvalidateMqttCredentialsRequest\x12\x10\n\x08user_ids\x18\x01 \x03(\t\"4\n!InvalidateMqttCredentialsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08*b\n\x0c\x44\x65viceStatus\x12\x1d\n\x19\x44\x45VICE_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x44\x45VICE_STATUS_ONLINE\x10\x01\x12\x19\n\x15\x44\x45VICE_STATUS_OFFLINE\x10\x02*k\n\tValueType\x12\x1a\n\x16VALUE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11VALUE_TYPE_NUMBER\x10\x01\x12\x16\n\x12VALUE_TYPE_BOOLEAN\x10\x02\x12\x13\n\x0fVALUE_TYPE_ENUM\x10\x03*_\n\rThresholdType\x12\x1e\n\x1aTHRESHOLD_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12THRESHOLD_TYPE_MIN\x10\x01\x12\x16\n\x12THRESHOLD_TYPE_MAX\x10\x02*x\n\x11ThresholdSeverity\x12\"\n\x1eTHRESHOLD_SEVERITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTHRESHOLD_SEVERITY_WARNING\x10\x01\x12\x1f\n\x1bTHRESHOLD_SEVERITY_CRITICAL\x10\x02\x32\xba\x11\n\x0e\x44\x65vicesService\x12K\n\x0c\x43reateDevice\x12\x1c.devices.CreateDeviceRequest\x1a\x1d.devices.CreateDeviceResponse\x12\x42\n\tGetDevice\x12\x19.devices.GetDeviceRequest\x1a\x1a.devices.GetDeviceResponse\x12H\n\x0bListDevices\x12\x1b.devices.ListDevicesRequest\x1a\x1c.devices.ListDevicesResponse\x12K\n\x0cUpdateDevice\x12\x1c.devices.UpdateDeviceRequest\x1a\x1d.devices.UpdateDeviceResponse\x12K\n\x0c\x44\x65leteDevice\x12\x1c.devices.DeleteDeviceRequest\x1a\x1d.devices.DeleteDeviceResponse\x12\x66\n\x15RegenerateDeviceToken\x12%.devices.RegenerateDeviceTokenRequest\x1a&.devices.RegenerateDeviceTokenResponse\x12K\n\x0c\x43reateSensor\x12\x1c.devices.CreateSensorRequest\x1a\x1d.devices.CreateSensorResponse\x12H\n\x0bListSensors\x12\x1b.devices.ListSensorsRequest\x1a\x1c.devices.ListSensorsResponse\x12K\n\x0cUpdateSensor\x12\x1c.devices.UpdateSensorRequest\x1a\x1d.devices.UpdateSensorResponse\x12K\n\x0c\x44\x65leteSensor\x12\x1c.devices.DeleteSensorRequest\x1a\x1d.devices.DeleteSensorResponse\x12K\n\x0cSetThreshold\x12\x1c.devices.SetThresholdRequest\x1a\x1d.devices.SetThresholdResponse\x12Q\n\x0eListThresholds\x12\x1e.devices.ListThresholdsRequest\x1a\x1f.devices.ListThresholdsResponse\x12T\n\x0f\x44\x65leteThreshold\x12\x1f.devices.DeleteThresholdRequest\x1a .devices.DeleteThresholdResponse\x12`\n\x13GetSensorThresholds\x12#.devices.GetSensorThresholdsRequest\x1a$.devices.GetSensorThresholdsResponse\x12Q\n\x0e\x43reateActuator\x12\x1e.devices.CreateActuatorRequest\x1a\x1f.devices.CreateActuatorResponse\x12N\n\rListActuators\x12\x1d.devices.ListActuatorsRequest\x1a\x1e.devices.ListActuatorsResponse\x12Q\n\x0eUpdateActuator\x12\x1e.devices.UpdateActuatorRequest\x1a\x1f.devices.UpdateActuatorResponse\x12Q\n\x0e\x44\x65leteActuator\x12\x1e.devices.DeleteActuatorRequest\x1a\x1f.devices.DeleteActuatorResponse\x12H\n\x0bSendCommand\x12\x1b.devices.SendCommandRequest\x1a\x1c.devices.SendCommandResponse\x12]\n\x12\x41uthenticateDevice\x12\".devices.AuthenticateDeviceRequest\x1a#.devices.AuthenticateDeviceResponse\x12Q\n\x0e\x43heckDeviceAcl\x12\x1e.devices.CheckDeviceAclRequest\x1a\x1f.devices.CheckDeviceAclResponse\x12l\n\x17GenerateMqttCredentials\x12\'.devices.GenerateMqttCredentialsRequest\x1a(.devices.GenerateMqttCredentialsResponse\x12]\n\x12UpdateDeviceStatus\x12\".devices.UpdateDeviceStatusRequest\x1a#.devices.UpdateDeviceStatusResponse\x12\x63\n\x14\x44\x65leteDevicesByPlace\x12$.devices.DeleteDevicesByPlaceRequest\x1a%.devices.DeleteDevicesByPlaceResponse\x12r\n\x19InvalidateMqttCredentials\x12).devices.InvalidateMqttCredentialsRequest\x1a*.devices.InvalidateMqttCredentialsResponse\x12W\n\x10GetAllThresholds\x12 .devices.GetAllThresholdsRequest\x1a!.devices.GetAllThresholdsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'devices_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEVICESTATUS']._serialized_start=5179
  _globals['_DEVICESTATUS']._serialized_end=5277
  _globals['_VALUETYPE']._serialized_start=5279
  _globals['_VALUETYPE']._serialized_end=5386
  _globals['_THRESHOLDTYPE']._serialized_start=5388
  _globals['_THRESHOLDTYPE']._serialized_end=5483
  _globals['_THRESHOLDSEVERITY']._serialized_start=5485
  _globals['_THRESHOLDSEVERITY']._serialized_end=5605
  _globals['_DEVICEINFO']._serialized_start=27
  _globals['_DEVICEINFO']._serialized_end=271
  _globals['_DEVICESUMMARY']._serialized_start=273
  _globals['_DEVICESUMMARY']._serialized_end=400
  _globals['_CREATEDEVICEREQUEST']._serialized_start=402
  _globals['_CREATEDEVICEREQUEST']._serialized_end=472
  _globals['_CREATEDEVICERESPONSE']._serialized_start=474
  _globals['_CREATEDEVICERESPONSE']._serialized_end=530
  _globals['_GETDEVICEREQUEST']._serialized_start=532
  _globals['_GETDEVICEREQUEST']._serialized_end=604
  _globals['_GETDEVICERESPONSE']._serialized_start=606
  _globals['_GETDEVICERESPONSE']._serialized_end=662
  _globals['_LISTDEVICESREQUEST']._serialized_start=664
  _globals['_LISTDEVICESREQUEST']._serialized_end=751
  _globals['_LISTDEVICESRESPONSE']._serialized_start=753
  _globals['_LISTDEVICESRESPONSE']._serialized_end=830
  _globals['_UPDATEDEVICEREQUEST']._serialized_start=832
  _globals['_UPDATEDEVICEREQUEST']._serialized_end=921
  _globals['_UPDATEDEVICERESPONSE']._serialized_start=923
  _globals['_UPDATEDEVICERESPONSE']._serialized_end=964
  _globals['_DELETEDEVICEREQUEST']._serialized_start=966
  _globals['_DELETEDEVICEREQUEST']._serialized_end=1041
  _globals['_DELETEDEVICERESPONSE']._serialized_start=1043
  _globals['_DELETEDEVICERESPONSE']._serialized_end=1082
  _globals['_REGENERATEDEVICETOKENREQUEST']._serialized_start=1084
  _globals['_REGENERATEDEVICETOKENREQUEST']._serialized_end=1168
  _globals['_REGENERATEDEVICETOKENRESPONSE']._serialized_start=1170
  _globals['_REGENERATEDEVICETOKENRESPONSE']._serialized_end=1216
  _globals['_SENSORINFO']._serialized_start=1219
  _globals['_SENSORINFO']._serialized_end=1375
  _globals['_CREATESENSORREQUEST']._serialized_start=1378
  _globals['_CREATESENSORREQUEST']._serialized_end=1559
  _globals['_CREATESENSORRESPONSE']._serialized_start=1561
  _globals['_CREATESENSORRESPONSE']._serialized_end=1602
  _globals['_LISTSENSORSREQUEST']._serialized_start=1604
  _globals['_LISTSENSORSREQUEST']._serialized_end=1678
  _globals['_LISTSENSORSRESPONSE']._serialized_start=1680
  _globals['_LISTSENSORSRESPONSE']._serialized_end=1739
  _globals['_UPDATESENSORREQUEST']._serialized_start=1742
  _globals['_UPDATESENSORREQUEST']._serialized_end=1889
  _globals['_UPDATESENSORRESPONSE']._serialized_start=1891
  _globals['_UPDATESENSORRESPONSE']._serialized_end=1932
  _globals['_DELETESENSORREQUEST']._serialized_start=1934
  _globals['_DELETESENSORREQUEST']._serialized_end=2028
  _globals['_DELETESENSORRESPONSE']._serialized_start=2030
  _globals['_DELETESENSORRESPONSE']._serialized_end=2069
  _globals['_THRESHOLDINFO']._serialized_start=2072
  _globals['_THRESHOLDINFO']._serialized_end=2227
  _globals['_SETTHRESHOLDREQUEST']._serialized_start=2230
  _globals['_SETTHRESHOLDREQUEST']._serialized_end=2423
  _globals['_SETTHRESHOLDRESPONSE']._serialized_start=2425
  _globals['_SETTHRESHOLDRESPONSE']._serialized_end=2469
  _globals['_LISTTHRESHOLDSREQUEST']._serialized_start=2471
  _globals['_LISTTHRESHOLDSREQUEST']._serialized_end=2567
  _globals['_LISTTHRESHOLDSRESPONSE']._serialized_start=2569
  _globals['_LISTTHRESHOLDSRESPONSE']._serialized_end=2637
  _globals['_DELETETHRESHOLDREQUEST']._serialized_start=2639
  _globals['_DELETETHRESHOLDREQUEST']._serialized_end=2758
  _globals['_DELETETHRESHOLDRESPONSE']._serialized_start=2760
  _globals['_DELETETHRESHOLDRESPONSE']._serialized_end=2802
  _globals['_GETSENSORTHRESHOLDSREQUEST']._serialized_start=2804
  _globals['_GETSENSORTHRESHOLDSREQUEST']._serialized_end=2851
  _globals['_GETSENSORTHRESHOLDSRESPONSE']._serialized_start=2853
  _globals['_GETSENSORTHRESHOLDSRESPONSE']._serialized_end=2926
  _globals['_ACTUATORINFO']._serialized_start=2929
  _globals['_ACTUATORINFO']._serialized_end=3163
  _globals['_CREATEACTUATORREQUEST']._serialized_start=3166
  _globals['_CREATEACTUATORREQUEST']._serialized_end=3423
  _globals['_CREATEACTUATORRESPONSE']._serialized_start=3425
  _globals['_CREATEACTUATORRESPONSE']._serialized_end=3470
  _globals['_LISTACTUATORSREQUEST']._serialized_start=3472
  _globals['_LISTACTUATORSREQUEST']._serialized_end=3548
  _globals['_LISTACTUATORSRESPONSE']._serialized_start=3550
  _globals['_LISTACTUATORSRESPONSE']._serialized_end=3615
  _globals['_UPDATEACTUATORREQUEST']._serialized_start=3618
  _globals['_UPDATEACTUATORREQUEST']._serialized_end=3843
  _globals['_UPDATEACTUATORRESPONSE']._serialized_start=3845
  _globals['_UPDATEACTUATORRESPONSE']._serialized_end=3890
  _globals['_DELETEACTUATORREQUEST']._serialized_start=3892
  _globals['_DELETEACTUATORREQUEST']._serialized_end=3990
  _globals['_DELETEACTUATORRESPONSE']._serialized_start=3992
  _globals['_DELETEACTUATORRESPONSE']._serialized_end=4033
  _globals['_SENDCOMMANDREQUEST']._serialized_start=4035
  _globals['_SENDCOMMANDREQUEST']._serialized_end=4146
  _globals['_SENDCOMMANDRESPONSE']._serialized_start=4148
  _globals['_SENDCOMMANDRESPONSE']._serialized_end=4186
  _globals['_AUTHENTICATEDEVICEREQUEST']._serialized_start=4188
  _globals['_AUTHENTICATEDEVICEREQUEST']._serialized_end=4251
  _globals['_AUTHENTICATEDEVICERESPONSE']._serialized_start=4253
  _globals['_AUTHENTICATEDEVICERESPONSE']._serialized_end=4296
  _globals['_CHECKDEVICEACLREQUEST']._serialized_start=4298
  _globals['_CHECKDEVICEACLREQUEST']._serialized_end=4370
  _globals['_CHECKDEVICEACLRESPONSE']._serialized_start=4372
  _globals['_CHECKDEVICEACLRESPONSE']._serialized_end=4411
  _globals['_GENERATEMQTTCREDENTIALSREQUEST']._serialized_start=4413
  _globals['_GENERATEMQTTCREDENTIALSREQUEST']._serialized_end=4462
  _globals['_GENERATEMQTTCREDENTIALSRESPONSE']._serialized_start=4464
  _globals['_GENERATEMQTTCREDENTIALSRESPONSE']._serialized_end=4553
  _globals['_UPDATEDEVICESTATUSREQUEST']._serialized_start=4555
  _globals['_UPDATEDEVICESTATUSREQUEST']._serialized_end=4640
  _globals['_UPDATEDEVICESTATUSRESPONSE']._serialized_start=4642
  _globals['_UPDATEDEVICESTATUSRESPONSE']._serialized_end=4687
  _globals['_DELETEDEVICESBYPLACEREQUEST']._serialized_start=4689
  _globals['_DELETEDEVICESBYPLACEREQUEST']._serialized_end=4736
  _globals['_DELETEDEVICESBYPLACERESPONSE']._serialized_start=4738
  _globals['_DELETEDEVICESBYPLACERESPONSE']._serialized_end=4828
  _globals['_GETALLTHRESHOLDSREQUEST']._serialized_start=4830
  _globals['_GETALLTHRESHOLDSREQUEST']._serialized_end=4855
  _globals['_SENSORWITHTHRESHOLDS']._serialized_start=4858
  _globals['_SENSORWITHTHRESHOLDS']._serialized_end=4993
  _globals['_GETALLTHRESHOLDSRESPONSE']._serialized_start=4995
  _globals['_GETALLTHRESHOLDSRESPONSE']._serialized_end=5069
  _globals['_INVALIDATEMQTTCREDENTIALSREQUEST']._serialized_start=5071
  _globals['_INVALIDATEMQTTCREDENTIALSREQUEST']._serialized_end=5123
  _globals['_INVALIDATEMQTTCREDENTIALSRESPONSE']._serialized_start=5125
  _globals['_INVALIDATEMQTTCREDENTIALSRESPONSE']._serialized_end=5177
  _globals['_DEVICESSERVICE']._serialized_start=5608
  _globals['_DEVICESSERVICE']._serialized_end=7842
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetLatestReadingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetLatestReadingsRequest: typing_extensions.TypeAlias = GetLatestReadingsRequest

@typing.final
class SensorReading(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.float
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.float = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["time", b"time"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["key", b"key", "time", b"time", "value", b"value"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SensorReading: typing_extensions.TypeAlias = SensorReading

@typing.final
class GetLatestReadingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    READINGS_FIELD_NUMBER: builtins.int
    @property
    def readings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___SensorReading]: ...
    def __init__(
        self,
        *,
        readings: collections.abc.Iterable[Global___SensorReading] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["readings", b"readings"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetLatestReadingsResponse: typing_extensions.TypeAlias = GetLatestReadingsResponse

@typing.final
class DeleteReadingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_IDS_FIELD_NUMBER: builtins.int
    @property
    def device_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        device_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_ids", b"device_ids"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteReadingsRequest: typing_extensions.TypeAlias = DeleteReadingsRequest

@typing.final
class DeleteReadingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteReadingsResponse: typing_extensions.TypeAlias = DeleteReadingsResponse

@typing.final
class GetReadingsRequest(google.protobuf.message.Message):
    """--- Historical readings ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    INTERVAL_SECONDS_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    interval_seconds: builtins.int
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def to(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
        to: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        interval_seconds: builtins.int = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["from", b"from", "to", b"to"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "from", b"from", "interval_seconds", b"interval_seconds", "keys", b"keys", "to", b"to"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetReadingsRequest: typing_extensions.TypeAlias = GetReadingsRequest

@typing.final
class AggregatedReading(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    AVG_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    avg: builtins.float
    min: builtins.float
    max: builtins.float
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        avg: builtins.float | None = ...,
        min: builtins.float | None = ...,
        max: builtins.float | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_avg", b"_avg", "_max", b"_max", "_min", b"_min", "avg", b"avg", "max", b"max", "min", b"min", "time", b"time"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_avg", b"_avg", "_max", b"_max", "_min", b"_min", "avg", b"avg", "max", b"max", "min", b"min", "time", b"time"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__avg: typing_extensions.TypeAlias = typing.Literal["avg"]
    _WhichOneofArgType__avg: typing_extensions.TypeAlias = typing.Literal["_avg", b"_avg"]
    _WhichOneofReturnType__max: typing_extensions.TypeAlias = typing.Literal["max"]
    _WhichOneofArgType__max: typing_extensions.TypeAlias = typing.Literal["_max", b"_max"]
    _WhichOneofReturnType__min: typing_extensions.TypeAlias = typing.Literal["min"]
    _WhichOneofArgType__min: typing_extensions.TypeAlias = typing.Literal["_min", b"_min"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__avg) -> _WhichOneofReturnType__avg | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__max) -> _WhichOneofReturnType__max | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__min) -> _WhichOneofReturnType__min | None: ...

Global___AggregatedReading: typing_extensions.TypeAlias = AggregatedReading

@typing.final
class KeyReadings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    POINTS_FIELD_NUMBER: builtins.int
    RAW_POINTS_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___AggregatedReading]: ...
    @property
    def raw_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___SensorReading]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        points: collections.abc.Iterable[Global___AggregatedReading] | None = ...,
        raw_points: collections.abc.Iterable[Global___SensorReading] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["key", b"key", "points", b"points", "raw_points", b"raw_points"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___KeyReadings: typing_extensions.TypeAlias = KeyReadings

@typing.final
class GetReadingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERIES_FIELD_NUMBER: builtins.int
    @property
    def series(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___KeyReadings]: ...
    def __init__(
        self,
        *,
        series: collections.abc.Iterable[Global___KeyReadings] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["series", b"series"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetReadingsResponse: typing_extensions.TypeAlias = GetReadingsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: collector.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'collector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63ollector.proto\x12\tcollector\x1a\x1fgoogle/protobuf/timestamp.proto\"-\n\x18GetLatestReadingsRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\"U\n\rSensorReading\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"G\n\x19GetLatestReadingsResponse\x12*\n\x08readings\x18\x01 \x03(\x0b\x32\x18.collector.SensorReading\"+\n\x15\x44\x65leteReadingsRequest\x12\x12\n\ndevice_ids\x18\x01 \x03(\t\")\n\x16\x44\x65leteReadingsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\xa1\x01\n\x12GetReadingsRequest\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12(\n\x04\x66rom\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02to\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10interval_seconds\x18\x05 \x01(\x05\"\x8b\x01\n\x11\x41ggregatedReading\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x03\x61vg\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12\x10\n\x03min\x18\x03 \x01(\x01H\x01\x88\x01\x01\x12\x10\n\x03max\x18\x04 \x01(\x01H\x02\x88\x01\x01\x42\x06\n\x04_avgB\x06\n\x04_minB\x06\n\x04_max\"v\n\x0bKeyReadings\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x06points\x18\x02 \x03(\x0b\x32\x1c.collector.AggregatedReading\x12,\n\nraw_points\x18\x03 \x03(\x0b\x32\x18.collector.SensorReading\"=\n\x13GetReadingsResponse\x12&\n\x06series\x18\x01 \x03(\x0b\x32\x16.collector.KeyReadings2\x97\x02\n\x10\x43ollectorService\x12^\n\x11GetLatestReadings\x12#.collector.GetLatestReadingsRequest\x1a$.collector.GetLatestReadingsResponse\x12U\n\x0e\x44\x65leteReadings\x12 .collector.DeleteReadingsRequest\x1a!.collector.DeleteReadingsResponse\x12L\n\x0bGetReadings\x12\x1d.collector.GetReadingsRequest\x1a\x1e.collector.GetReadingsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'collector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETLATESTREADINGSREQUEST']._serialized_start=63
  _globals['_GETLATESTREADINGSREQUEST']._serialized_end=108
  _globals['_SENSORREADING']._serialized_start=110
  _globals['_SENSORREADING']._serialized_end=195
  _globals['_GETLATESTREADINGSRESPONSE']._serialized_start=197
  _globals['_GETLATESTREADINGSRESPONSE']._serialized_end=268
  _globals['_DELETEREADINGSREQUEST']._serialized_start=270
  _globals['_DELETEREADINGSREQUEST']._serialized_end=313
  _globals['_DELETEREADINGSRESPONSE']._serialized_start=315
  _globals['_DELETEREADINGSRESPONSE']._serialized_end=356
  _globals['_GETREADINGSREQUEST']._serialized_start=359
  _globals['_GETREADINGSREQUEST']._serialized_end=520
  _globals['_AGGREGATEDREADING']._serialized_start=523
  _globals['_AGGREGATEDREADING']._serialized_end=662
  _globals['_KEYREADINGS']._serialized_start=664
  _globals['_KEYREADINGS']._serialized_end=782
  _globals['_GETREADINGSRESPONSE']._serialized_start=784
  _globals['_GETREADINGSRESPONSE']._serialized_end=845
  _globals['_COLLECTORSERVICE']._serialized_start=848
  _globals['_COLLECTORSERVICE']._serialized_end=1127
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DeviceStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_STATUS_UNSPECIFIED: _DeviceStatus.ValueType  # 0
    DEVICE_STATUS_ONLINE: _DeviceStatus.ValueType  # 1
    DEVICE_STATUS_OFFLINE: _DeviceStatus.ValueType  # 2

class DeviceStatus(_DeviceStatus, metaclass=_DeviceStatusEnumTypeWrapper):
    """--- Enums ---"""

DEVICE_STATUS_UNSPECIFIED: DeviceStatus.ValueType  # 0
DEVICE_STATUS_ONLINE: DeviceStatus.ValueType  # 1
DEVICE_STATUS_OFFLINE: DeviceStatus.ValueType  # 2
Global___DeviceStatus: typing_extensions.TypeAlias = DeviceStatus

class _ValueType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ValueTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ValueType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VALUE_TYPE_UNSPECIFIED: _ValueType.ValueType  # 0
    VALUE_TYPE_NUMBER: _ValueType.ValueType  # 1
    VALUE_TYPE_BOOLEAN: _ValueType.ValueType  # 2
    VALUE_TYPE_ENUM: _ValueType.ValueType  # 3

class ValueType(_ValueType, metaclass=_ValueTypeEnumTypeWrapper): ...

VALUE_TYPE_UNSPECIFIED: ValueType.ValueType  # 0
VALUE_TYPE_NUMBER: ValueType.ValueType  # 1
VALUE_TYPE_BOOLEAN: ValueType.ValueType  # 2
VALUE_TYPE_ENUM: ValueType.ValueType  # 3
Global___ValueType: typing_extensions.TypeAlias = ValueType

class _ThresholdType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThresholdTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThresholdType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    THRESHOLD_TYPE_UNSPECIFIED: _ThresholdType.ValueType  # 0
    THRESHOLD_TYPE_MIN: _ThresholdType.ValueType  # 1
    THRESHOLD_TYPE_MAX: _ThresholdType.ValueType  # 2

class ThresholdType(_ThresholdType, metaclass=_ThresholdTypeEnumTypeWrapper): ...

THRESHOLD_TYPE_UNSPECIFIED: ThresholdType.ValueType  # 0
THRESHOLD_TYPE_MIN: ThresholdType.ValueType  # 1
THRESHOLD_TYPE_MAX: ThresholdType.ValueType  # 2
Global___ThresholdType: typing_extensions.TypeAlias = ThresholdType

class _ThresholdSeverity:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ThresholdSeverityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ThresholdSeverity.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    THRESHOLD_SEVERITY_UNSPECIFIED: _ThresholdSeverity.ValueType  # 0
    THRESHOLD_SEVERITY_WARNING: _ThresholdSeverity.ValueType  # 1
    THRESHOLD_SEVERITY_CRITICAL: _ThresholdSeverity.ValueType  # 2

class ThresholdSeverity(_ThresholdSeverity, metaclass=_ThresholdSeverityEnumTypeWrapper): ...

THRESHOLD_SEVERITY_UNSPECIFIED: ThresholdSeverity.ValueType  # 0
THRESHOLD_SEVERITY_WARNING: ThresholdSeverity.ValueType  # 1
THRESHOLD_SEVERITY_CRITICAL: ThresholdSeverity.ValueType  # 2
Global___ThresholdSeverity: typing_extensions.TypeAlias = ThresholdSeverity

@typing.final
class DeviceInfo(google.protobuf.message.Message):
    """--- Device messages ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LAST_SEEN_AT_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    SENSORS_FIELD_NUMBER: builtins.int
    ACTUATORS_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    place_id: builtins.str
    name: builtins.str
    status: Global___DeviceStatus.ValueType
    last_seen_at: builtins.str
    created_at: builtins.str
    updated_at: builtins.str
    @property
    def sensors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___SensorInfo]: ...
    @property
    def actuators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ActuatorInfo]: ...
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        status: Global___DeviceStatus.ValueType = ...,
        last_seen_at: builtins.str = ...,
        created_at: builtins.str = ...,
        updated_at: builtins.str = ...,
        sensors: collections.abc.Iterable[Global___SensorInfo] | None = ...,
        actuators: collections.abc.Iterable[Global___ActuatorInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuators", b"actuators", "created_at", b"created_at", "device_id", b"device_id", "last_seen_at", b"last_seen_at", "name", b"name", "place_id", b"place_id", "sensors", b"sensors", "status", b"status", "updated_at", b"updated_at"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeviceInfo: typing_extensions.TypeAlias = DeviceInfo

@typing.final
class DeviceSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LAST_SEEN_AT_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    place_id: builtins.str
    name: builtins.str
    status: Global___DeviceStatus.ValueType
    last_seen_at: builtins.str
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        status: Global___DeviceStatus.ValueType = ...,
        last_seen_at: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "last_seen_at", b"last_seen_at", "name", b"name", "place_id", b"place_id", "status", b"status"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeviceSummary: typing_extensions.TypeAlias = DeviceSummary

@typing.final
class CreateDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["name", b"name", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateDeviceRequest: typing_extensions.TypeAlias = CreateDeviceRequest

@typing.final
class CreateDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    token: builtins.str
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "token", b"token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateDeviceResponse: typing_extensions.TypeAlias = CreateDeviceResponse

@typing.final
class GetDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetDeviceRequest: typing_extensions.TypeAlias = GetDeviceRequest

@typing.final
class GetDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_FIELD_NUMBER: builtins.int
    @property
    def device(self) -> Global___DeviceInfo: ...
    def __init__(
        self,
        *,
        device: Global___DeviceInfo | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["device", b"device"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device", b"device"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetDeviceResponse: typing_extensions.TypeAlias = GetDeviceResponse

@typing.final
class ListDevicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PER_PAGE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    page: builtins.int
    per_page: builtins.int
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        page: builtins.int = ...,
        per_page: builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page", b"page", "per_page", b"per_page", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListDevicesRequest: typing_extensions.TypeAlias = ListDevicesRequest

@typing.final
class ListDevicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICES_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    total: builtins.int
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___DeviceSummary]: ...
    def __init__(
        self,
        *,
        devices: collections.abc.Iterable[Global___DeviceSummary] | None = ...,
        total: builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["devices", b"devices", "total", b"total"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListDevicesResponse: typing_extensions.TypeAlias = ListDevicesResponse

@typing.final
class UpdateDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "name", b"name", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateDeviceRequest: typing_extensions.TypeAlias = UpdateDeviceRequest

@typing.final
class UpdateDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateDeviceResponse: typing_extensions.TypeAlias = UpdateDeviceResponse

@typing.final
class DeleteDeviceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteDeviceRequest: typing_extensions.TypeAlias = DeleteDeviceRequest

@typing.final
class DeleteDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteDeviceResponse: typing_extensions.TypeAlias = DeleteDeviceResponse

@typing.final
class RegenerateDeviceTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RegenerateDeviceTokenRequest: typing_extensions.TypeAlias = RegenerateDeviceTokenRequest

@typing.final
class RegenerateDeviceTokenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    token: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["token", b"token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RegenerateDeviceTokenResponse: typing_extensions.TypeAlias = RegenerateDeviceTokenResponse

@typing.final
class SensorInfo(google.protobuf.message.Message):
    """--- Sensor messages ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENSOR_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    UNIT_LABEL_FIELD_NUMBER: builtins.int
    PRECISION_FIELD_NUMBER: builtins.int
    sensor_id: builtins.str
    device_id: builtins.str
    key: builtins.str
    name: builtins.str
    value_type: Global___ValueType.ValueType
    unit_label: builtins.str
    precision: builtins.int
    def __init__(
        self,
        *,
        sensor_id: builtins.str = ...,
        device_id: builtins.str = ...,
        key: builtins.str = ...,
        name: builtins.str = ...,
        value_type: Global___ValueType.ValueType = ...,
        unit_label: builtins.str = ...,
        precision: builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "key", b"key", "name", b"name", "precision", b"precision", "sensor_id", b"sensor_id", "unit_label", b"unit_label", "value_type", b"value_type"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SensorInfo: typing_extensions.TypeAlias = SensorInfo

@typing.final
class CreateSensorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    UNIT_LABEL_FIELD_NUMBER: builtins.int
    PRECISION_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    key: builtins.str
    name: builtins.str
    value_type: Global___ValueType.ValueType
    unit_label: builtins.str
    precision: builtins.int
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        key: builtins.str = ...,
        name: builtins.str = ...,
        value_type: Global___ValueType.ValueType = ...,
        unit_label: builtins.str = ...,
        precision: builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "key", b"key", "name", b"name", "place_id", b"place_id", "precision", b"precision", "unit_label", b"unit_label", "user_id", b"user_id", "value_type", b"value_type"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateSensorRequest: typing_extensions.TypeAlias = CreateSensorRequest

@typing.final
class CreateSensorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENSOR_ID_FIELD_NUMBER: builtins.int
    sensor_id: builtins.str
    def __init__(
        self,
        *,
        sensor_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["sensor_id", b"sensor_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateSensorResponse: typing_extensions.TypeAlias = CreateSensorResponse

@typing.final
class ListSensorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListSensorsRequest: typing_extensions.TypeAlias = ListSensorsRequest

@typing.final
class ListSensorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENSORS_FIELD_NUMBER: builtins.int
    @property
    def sensors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___SensorInfo]: ...
    def __init__(
        self,
        *,
        sensors: collections.abc.Iterable[Global___SensorInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["sensors", b"sensors"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListSensorsResponse: typing_extensions.TypeAlias = ListSensorsResponse

@typing.final
class UpdateSensorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    SENSOR_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UNIT_LABEL_FIELD_NUMBER: builtins.int
    PRECISION_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    sensor_id: builtins.str
    name: builtins.str
    unit_label: builtins.str
    precision: builtins.int
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        sensor_id: builtins.str = ...,
        name: builtins.str = ...,
        unit_label: builtins.str = ...,
        precision: builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "name", b"name", "place_id", b"place_id", "precision", b"precision", "sensor_id", b"sensor_id", "unit_label", b"unit_label", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateSensorRequest: typing_extensions.TypeAlias = UpdateSensorRequest

@typing.final
class UpdateSensorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENSOR_ID_FIELD_NUMBER: builtins.int
    sensor_id: builtins.str
    def __init__(
        self,
        *,
        sensor_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["sensor_id", b"sensor_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateSensorResponse: typing_extensions.TypeAlias = UpdateSensorResponse

@typing.final
class DeleteSensorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    SENSOR_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    sensor_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        sensor_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "sensor_id", b"sensor_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteSensorRequest: typing_extensions.TypeAlias = DeleteSensorRequest

@typing.final
class DeleteSensorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteSensorResponse: typing_extensions.TypeAlias = DeleteSensorResponse

@typing.final
class ThresholdInfo(google.protobuf.message.Message):
    """--- Threshold messages ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THRESHOLD_ID_FIELD_NUMBER: builtins.int
    SENSOR_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    SEVERITY_FIELD_NUMBER: builtins.int
    threshold_id: builtins.str
    sensor_id: builtins.str
    type: Global___ThresholdType.ValueType
    value: builtins.float
    severity: Global___ThresholdSeverity.ValueType
    def __init__(
        self,
        *,
        threshold_id: builtins.str = ...,
        sensor_id: builtins.str = ...,
        type: Global___ThresholdType.ValueType = ...,
        value: builtins.float = ...,
        severity: Global___ThresholdSeverity.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["sensor_id", b"sensor_id", "severity", b"severity", "threshold_id", b"threshold_id", "type", b"type", "value", b"value"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ThresholdInfo: typing_extensions.TypeAlias = ThresholdInfo

@typing.final
class SetThresholdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    SENSOR_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    SEVERITY_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    sensor_id: builtins.str
    type: Global___ThresholdType.ValueType
    value: builtins.float
    severity: Global___ThresholdSeverity.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        sensor_id: builtins.str = ...,
        type: Global___ThresholdType.ValueType = ...,
        value: builtins.float = ...,
        severity: Global___ThresholdSeverity.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "sensor_id", b"sensor_id", "severity", b"severity", "type", b"type", "user_id", b"user_id", "value", b"value"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetThresholdRequest: typing_extensions.TypeAlias = SetThresholdRequest

@typing.final
class SetThresholdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THRESHOLD_ID_FIELD_NUMBER: builtins.int
    threshold_id: builtins.str
    def __init__(
        self,
        *,
        threshold_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["threshold_id", b"threshold_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetThresholdResponse: typing_extensions.TypeAlias = SetThresholdResponse

@typing.final
class ListThresholdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    SENSOR_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    sensor_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        sensor_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "sensor_id", b"sensor_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListThresholdsRequest: typing_extensions.TypeAlias = ListThresholdsRequest

@typing.final
class ListThresholdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THRESHOLDS_FIELD_NUMBER: builtins.int
    @property
    def thresholds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ThresholdInfo]: ...
    def __init__(
        self,
        *,
        thresholds: collections.abc.Iterable[Global___ThresholdInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["thresholds", b"thresholds"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListThresholdsResponse: typing_extensions.TypeAlias = ListThresholdsResponse

@typing.final
class DeleteThresholdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    SENSOR_ID_FIELD_NUMBER: builtins.int
    THRESHOLD_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    sensor_id: builtins.str
    threshold_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        sensor_id: builtins.str = ...,
        threshold_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "sensor_id", b"sensor_id", "threshold_id", b"threshold_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteThresholdRequest: typing_extensions.TypeAlias = DeleteThresholdRequest

@typing.final
class DeleteThresholdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteThresholdResponse: typing_extensions.TypeAlias = DeleteThresholdResponse

@typing.final
class GetSensorThresholdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENSOR_ID_FIELD_NUMBER: builtins.int
    sensor_id: builtins.str
    def __init__(
        self,
        *,
        sensor_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["sensor_id", b"sensor_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetSensorThresholdsRequest: typing_extensions.TypeAlias = GetSensorThresholdsRequest

@typing.final
class GetSensorThresholdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THRESHOLDS_FIELD_NUMBER: builtins.int
    @property
    def thresholds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ThresholdInfo]: ...
    def __init__(
        self,
        *,
        thresholds: collections.abc.Iterable[Global___ThresholdInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["thresholds", b"thresholds"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetSensorThresholdsResponse: typing_extensions.TypeAlias = GetSensorThresholdsResponse

@typing.final
class ActuatorInfo(google.protobuf.message.Message):
    """--- Actuator messages ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTUATOR_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    UNIT_LABEL_FIELD_NUMBER: builtins.int
    PRECISION_FIELD_NUMBER: builtins.int
    MIN_VALUE_FIELD_NUMBER: builtins.int
    MAX_VALUE_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    ENUM_OPTIONS_FIELD_NUMBER: builtins.int
    actuator_id: builtins.str
    device_id: builtins.str
    key: builtins.str
    name: builtins.str
    value_type: Global___ValueType.ValueType
    unit_label: builtins.str
    precision: builtins.int
    min_value: builtins.float
    max_value: builtins.float
    step: builtins.float
    @property
    def enum_options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        actuator_id: builtins.str = ...,
        device_id: builtins.str = ...,
        key: builtins.str = ...,
        name: builtins.str = ...,
        value_type: Global___ValueType.ValueType = ...,
        unit_label: builtins.str = ...,
        precision: builtins.int = ...,
        min_value: builtins.float = ...,
        max_value: builtins.float = ...,
        step: builtins.float = ...,
        enum_options: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuator_id", b"actuator_id", "device_id", b"device_id", "enum_options", b"enum_options", "key", b"key", "max_value", b"max_value", "min_value", b"min_value", "name", b"name", "precision", b"precision", "step", b"step", "unit_label", b"unit_label", "value_type", b"value_type"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ActuatorInfo: typing_extensions.TypeAlias = ActuatorInfo

@typing.final
class CreateActuatorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    UNIT_LABEL_FIELD_NUMBER: builtins.int
    PRECISION_FIELD_NUMBER: builtins.int
    MIN_VALUE_FIELD_NUMBER: builtins.int
    MAX_VALUE_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    ENUM_OPTIONS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    key: builtins.str
    name: builtins.str
    value_type: Global___ValueType.ValueType
    unit_label: builtins.str
    precision: builtins.int
    min_value: builtins.float
    max_value: builtins.float
    step: builtins.float
    @property
    def enum_options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        key: builtins.str = ...,
        name: builtins.str = ...,
        value_type: Global___ValueType.ValueType = ...,
        unit_label: builtins.str = ...,
        precision: builtins.int = ...,
        min_value: builtins.float = ...,
        max_value: builtins.float = ...,
        step: builtins.float = ...,
        enum_options: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "enum_options", b"enum_options", "key", b"key", "max_value", b"max_value", "min_value", b"min_value", "name", b"name", "place_id", b"place_id", "precision", b"precision", "step", b"step", "unit_label", b"unit_label", "user_id", b"user_id", "value_type", b"value_type"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateActuatorRequest: typing_extensions.TypeAlias = CreateActuatorRequest

@typing.final
class CreateActuatorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTUATOR_ID_FIELD_NUMBER: builtins.int
    actuator_id: builtins.str
    def __init__(
        self,
        *,
        actuator_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuator_id", b"actuator_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateActuatorResponse: typing_extensions.TypeAlias = CreateActuatorResponse

@typing.final
class ListActuatorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListActuatorsRequest: typing_extensions.TypeAlias = ListActuatorsRequest

@typing.final
class ListActuatorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTUATORS_FIELD_NUMBER: builtins.int
    @property
    def actuators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ActuatorInfo]: ...
    def __init__(
        self,
        *,
        actuators: collections.abc.Iterable[Global___ActuatorInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuators", b"actuators"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListActuatorsResponse: typing_extensions.TypeAlias = ListActuatorsResponse

@typing.final
class UpdateActuatorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    ACTUATOR_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UNIT_LABEL_FIELD_NUMBER: builtins.int
    PRECISION_FIELD_NUMBER: builtins.int
    MIN_VALUE_FIELD_NUMBER: builtins.int
    MAX_VALUE_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    ENUM_OPTIONS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    actuator_id: builtins.str
    name: builtins.str
    unit_label: builtins.str
    precision: builtins.int
    min_value: builtins.float
    max_value: builtins.float
    step: builtins.float
    @property
    def enum_options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        actuator_id: builtins.str = ...,
        name: builtins.str = ...,
        unit_label: builtins.str = ...,
        precision: builtins.int = ...,
        min_value: builtins.float = ...,
        max_value: builtins.float = ...,
        step: builtins.float = ...,
        enum_options: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuator_id", b"actuator_id", "device_id", b"device_id", "enum_options", b"enum_options", "max_value", b"max_value", "min_value", b"min_value", "name", b"name", "place_id", b"place_id", "precision", b"precision", "step", b"step", "unit_label", b"unit_label", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateActuatorRequest: typing_extensions.TypeAlias = UpdateActuatorRequest

@typing.final
class UpdateActuatorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTUATOR_ID_FIELD_NUMBER: builtins.int
    actuator_id: builtins.str
    def __init__(
        self,
        *,
        actuator_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuator_id", b"actuator_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateActuatorResponse: typing_extensions.TypeAlias = UpdateActuatorResponse

@typing.final
class DeleteActuatorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    ACTUATOR_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    actuator_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        actuator_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuator_id", b"actuator_id", "device_id", b"device_id", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteActuatorRequest: typing_extensions.TypeAlias = DeleteActuatorRequest

@typing.final
class DeleteActuatorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteActuatorResponse: typing_extensions.TypeAlias = DeleteActuatorResponse

@typing.final
class SendCommandRequest(google.protobuf.message.Message):
    """--- Command messages ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    ACTUATOR_KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    device_id: builtins.str
    actuator_key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        device_id: builtins.str = ...,
        actuator_key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["actuator_key", b"actuator_key", "device_id", b"device_id", "place_id", b"place_id", "user_id", b"user_id", "value", b"value"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendCommandRequest: typing_extensions.TypeAlias = SendCommandRequest

@typing.final
class SendCommandResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendCommandResponse: typing_extensions.TypeAlias = SendCommandResponse

@typing.final
class AuthenticateDeviceRequest(google.protobuf.message.Message):
    """--- MQTT auth messages ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    username: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["password", b"password", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AuthenticateDeviceRequest: typing_extensions.TypeAlias = AuthenticateDeviceRequest

@typing.final
class AuthenticateDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_FIELD_NUMBER: builtins.int
    allow: builtins.bool
    def __init__(
        self,
        *,
        allow: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["allow", b"allow"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AuthenticateDeviceResponse: typing_extensions.TypeAlias = AuthenticateDeviceResponse

@typing.final
class CheckDeviceAclRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    username: builtins.str
    topic: builtins.str
    action: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        topic: builtins.str = ...,
        action: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["action", b"action", "topic", b"topic", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckDeviceAclRequest: typing_extensions.TypeAlias = CheckDeviceAclRequest

@typing.final
class CheckDeviceAclResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_FIELD_NUMBER: builtins.int
    allow: builtins.bool
    def __init__(
        self,
        *,
        allow: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["allow", b"allow"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckDeviceAclResponse: typing_extensions.TypeAlias = CheckDeviceAclResponse

@typing.final
class GenerateMqttCredentialsRequest(google.protobuf.message.Message):
    """--- MQTT credentials ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GenerateMqttCredentialsRequest: typing_extensions.TypeAlias = GenerateMqttCredentialsRequest

@typing.final
class GenerateMqttCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    username: builtins.str
    password: builtins.str
    expires_at: builtins.int
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        password: builtins.str = ...,
        expires_at: builtins.int = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["expires_at", b"expires_at", "password", b"password", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GenerateMqttCredentialsResponse: typing_extensions.TypeAlias = GenerateMqttCredentialsResponse

@typing.final
class UpdateDeviceStatusRequest(google.protobuf.message.Message):
    """--- Device status ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    status: Global___DeviceStatus.ValueType
    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        status: Global___DeviceStatus.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "status", b"status"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateDeviceStatusRequest: typing_extensions.TypeAlias = UpdateDeviceStatusRequest

@typing.final
class UpdateDeviceStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateDeviceStatusResponse: typing_extensions.TypeAlias = UpdateDeviceStatusResponse

@typing.final
class DeleteDevicesByPlaceRequest(google.protobuf.message.Message):
    """--- DeleteDevicesByPlace (internal) ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteDevicesByPlaceRequest: typing_extensions.TypeAlias = DeleteDevicesByPlaceRequest

@typing.final
class DeleteDevicesByPlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    DELETED_COUNT_FIELD_NUMBER: builtins.int
    DEVICE_IDS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    deleted_count: builtins.int
    @property
    def device_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        deleted_count: builtins.int = ...,
        device_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["deleted_count", b"deleted_count", "device_ids", b"device_ids", "success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeleteDevicesByPlaceResponse: typing_extensions.TypeAlias = DeleteDevicesByPlaceResponse

@typing.final
class GetAllThresholdsRequest(google.protobuf.message.Message):
    """--- GetAllThresholds (for collector) ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___GetAllThresholdsRequest: typing_extensions.TypeAlias = GetAllThresholdsRequest

@typing.final
class SensorWithThresholds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENSOR_ID_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    THRESHOLDS_FIELD_NUMBER: builtins.int
    sensor_id: builtins.str
    device_id: builtins.str
    place_id: builtins.str
    key: builtins.str
    @property
    def thresholds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ThresholdInfo]: ...
    def __init__(
        self,
        *,
        sensor_id: builtins.str = ...,
        device_id: builtins.str = ...,
        place_id: builtins.str = ...,
        key: builtins.str = ...,
        thresholds: collections.abc.Iterable[Global___ThresholdInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["device_id", b"device_id", "key", b"key", "place_id", b"place_id", "sensor_id", b"sensor_id", "thresholds", b"thresholds"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SensorWithThresholds: typing_extensions.TypeAlias = SensorWithThresholds

@typing.final
class GetAllThresholdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENSORS_FIELD_NUMBER: builtins.int
    @property
    def sensors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___SensorWithThresholds]: ...
    def __init__(
        self,
        *,
        sensors: collections.abc.Iterable[Global___SensorWithThresholds] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["sensors", b"sensors"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetAllThresholdsResponse: typing_extensions.TypeAlias = GetAllThresholdsResponse

@typing.final
class InvalidateMqttCredentialsRequest(google.protobuf.message.Message):
    """--- InvalidateMqttCredentials (internal) ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_IDS_FIELD_NUMBER: builtins.int
    @property
    def user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        user_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_ids", b"user_ids"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InvalidateMqttCredentialsRequest: typing_extensions.TypeAlias = InvalidateMqttCredentialsRequest

@typing.final
class InvalidateMqttCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InvalidateMqttCredentialsResponse: typing_extensions.TypeAlias = InvalidateMqttCredentialsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import auth_pb2
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class AuthServiceStub:
    @typing.overload
    def __new__(cls, channel: grpc.Channel) -> AuthServiceStub: ...
    @typing.overload
    def __new__(cls, channel: grpc.aio.Channel) -> AuthServiceAsyncStub: ...
    Register: grpc.UnaryUnaryMultiCallable[auth_pb2.RegisterRequest, auth_pb2.RegisterResponse]
    Login: grpc.UnaryUnaryMultiCallable[auth_pb2.LoginRequest, auth_pb2.LoginResponse]
    RefreshTokens: grpc.UnaryUnaryMultiCallable[auth_pb2.RefreshTokensRequest, auth_pb2.RefreshTokensResponse]
    Logout: grpc.UnaryUnaryMultiCallable[auth_pb2.LogoutRequest, auth_pb2.LogoutResponse]
    GetMe: grpc.UnaryUnaryMultiCallable[auth_pb2.GetMeRequest, auth_pb2.GetMeResponse]
    GetUserByEmail: grpc.UnaryUnaryMultiCallable[auth_pb2.GetUserByEmailRequest, auth_pb2.GetUserByEmailResponse]
    ValidateToken: grpc.UnaryUnaryMultiCallable[auth_pb2.ValidateTokenRequest, auth_pb2.ValidateTokenResponse]
    SendOtp: grpc.UnaryUnaryMultiCallable[auth_pb2.SendOtpRequest, auth_pb2.SendOtpResponse]
    VerifyOtp: grpc.UnaryUnaryMultiCallable[auth_pb2.VerifyOtpRequest, auth_pb2.VerifyOtpResponse]

@typing.type_check_only
class AuthServiceAsyncStub(AuthServiceStub):
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    Register: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.RegisterRequest, auth_pb2.RegisterResponse]  # type: ignore[assignment]
    Login: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.LoginRequest, auth_pb2.LoginResponse]  # type: ignore[assignment]
    RefreshTokens: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.RefreshTokensRequest, auth_pb2.RefreshTokensResponse]  # type: ignore[assignment]
    Logout: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.LogoutRequest, auth_pb2.LogoutResponse]  # type: ignore[assignment]
    GetMe: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.GetMeRequest, auth_pb2.GetMeResponse]  # type: ignore[assignment]
    GetUserByEmail: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.GetUserByEmailRequest, auth_pb2.GetUserByEmailResponse]  # type: ignore[assignment]
    ValidateToken: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.ValidateTokenRequest, auth_pb2.ValidateTokenResponse]  # type: ignore[assignment]
    SendOtp: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.SendOtpRequest, auth_pb2.SendOtpResponse]  # type: ignore[assignment]
    VerifyOtp: grpc.aio.UnaryUnaryMultiCallable[auth_pb2.VerifyOtpRequest, auth_pb2.VerifyOtpResponse]  # type: ignore[assignment]

class AuthServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Register(
        self,
        request: auth_pb2.RegisterRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.RegisterResponse, collections.abc.Awaitable[auth_pb2.RegisterResponse]]: ...

    @abc.abstractmethod
    def Login(
        self,
        request: auth_pb2.LoginRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.LoginResponse, collections.abc.Awaitable[auth_pb2.LoginResponse]]: ...

    @abc.abstractmethod
    def RefreshTokens(
        self,
        request: auth_pb2.RefreshTokensRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.RefreshTokensResponse, collections.abc.Awaitable[auth_pb2.RefreshTokensResponse]]: ...

    @abc.abstractmethod
    def Logout(
        self,
        request: auth_pb2.LogoutRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.LogoutResponse, collections.abc.Awaitable[auth_pb2.LogoutResponse]]: ...

    @abc.abstractmethod
    def GetMe(
        self,
        request: auth_pb2.GetMeRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.GetMeResponse, collections.abc.Awaitable[auth_pb2.GetMeResponse]]: ...

    @abc.abstractmethod
    def GetUserByEmail(
        self,
        request: auth_pb2.GetUserByEmailRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.GetUserByEmailResponse, collections.abc.Awaitable[auth_pb2.GetUserByEmailResponse]]: ...

    @abc.abstractmethod
    def ValidateToken(
        self,
        request: auth_pb2.ValidateTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.ValidateTokenResponse, collections.abc.Awaitable[auth_pb2.ValidateTokenResponse]]: ...

    @abc.abstractmethod
    def SendOtp(
        self,
        request: auth_pb2.SendOtpRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.SendOtpResponse, collections.abc.Awaitable[auth_pb2.SendOtpResponse]]: ...

    @abc.abstractmethod
    def VerifyOtp(
        self,
        request: auth_pb2.VerifyOtpRequest,
        context: _ServicerContext,
    ) -> typing.Union[auth_pb2.VerifyOtpResponse, collections.abc.Awaitable[auth_pb2.VerifyOtpResponse]]: ...

def add_AuthServiceServicer_to_server(servicer: AuthServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import collector_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class CollectorServiceStub:
    @typing.overload
    def __new__(cls, channel: grpc.Channel) -> CollectorServiceStub: ...
    @typing.overload
    def __new__(cls, channel: grpc.aio.Channel) -> CollectorServiceAsyncStub: ...
    GetLatestReadings: grpc.UnaryUnaryMultiCallable[collector_pb2.GetLatestReadingsRequest, collector_pb2.GetLatestReadingsResponse]
    DeleteReadings: grpc.UnaryUnaryMultiCallable[collector_pb2.DeleteReadingsRequest, collector_pb2.DeleteReadingsResponse]
    GetReadings: grpc.UnaryUnaryMultiCallable[collector_pb2.GetReadingsRequest, collector_pb2.GetReadingsResponse]

@typing.type_check_only
class CollectorServiceAsyncStub(CollectorServiceStub):
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    GetLatestReadings: grpc.aio.UnaryUnaryMultiCallable[collector_pb2.GetLatestReadingsRequest, collector_pb2.GetLatestReadingsResponse]  # type: ignore[assignment]
    DeleteReadings: grpc.aio.UnaryUnaryMultiCallable[collector_pb2.DeleteReadingsRequest, collector_pb2.DeleteReadingsResponse]  # type: ignore[assignment]
    GetReadings: grpc.aio.UnaryUnaryMultiCallable[collector_pb2.GetReadingsRequest, collector_pb2.GetReadingsResponse]  # type: ignore[assignment]

class CollectorServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetLatestReadings(
        self,
        request: collector_pb2.GetLatestReadingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collector_pb2.GetLatestReadingsResponse, collections.abc.Awaitable[collector_pb2.GetLatestReadingsResponse]]: ...

    @abc.abstractmethod
    def DeleteReadings(
        self,
        request: collector_pb2.DeleteReadingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collector_pb2.DeleteReadingsResponse, collections.abc.Awaitable[collector_pb2.DeleteReadingsResponse]]: ...

    @abc.abstractmethod
    def GetReadings(
        self,
        request: collector_pb2.GetReadingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collector_pb2.GetReadingsResponse, collections.abc.Awaitable[collector_pb2.GetReadingsResponse]]: ...

def add_CollectorServiceServicer_to_server(servicer: CollectorServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ROLE_UNSPECIFIED: _Role.ValueType  # 0
    ROLE_OWNER: _Role.ValueType  # 1
    ROLE_ADMIN: _Role.ValueType  # 2
    ROLE_VIEWER: _Role.ValueType  # 3

class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...

ROLE_UNSPECIFIED: Role.ValueType  # 0
ROLE_OWNER: Role.ValueType  # 1
ROLE_ADMIN: Role.ValueType  # 2
ROLE_VIEWER: Role.ValueType  # 3
Global___Role: typing_extensions.TypeAlias = Role

@typing.final
class CreatePlaceRequest(google.protobuf.message.Message):
    """--- Places ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    name: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreatePlaceRequest: typing_extensions.TypeAlias = CreatePlaceRequest

@typing.final
class CreatePlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreatePlaceResponse: typing_extensions.TypeAlias = CreatePlaceResponse

@typing.final
class GetPlaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetPlaceRequest: typing_extensions.TypeAlias = GetPlaceRequest

@typing.final
class GetPlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    USER_ROLE_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    name: builtins.str
    description: builtins.str
    user_role: Global___Role.ValueType
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        user_role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "place_id", b"place_id", "user_role", b"user_role"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetPlaceResponse: typing_extensions.TypeAlias = GetPlaceResponse

@typing.final
class ListPlacesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPlacesRequest: typing_extensions.TypeAlias = ListPlacesRequest

@typing.final
class ListPlacesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACES_FIELD_NUMBER: builtins.int
    @property
    def places(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___PlaceSummary]: ...
    def __init__(
        self,
        *,
        places: collections.abc.Iterable[Global___PlaceSummary] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["places", b"places"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPlacesResponse: typing_extensions.TypeAlias = ListPlacesResponse

@typing.final
class PlaceSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    USER_ROLE_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    name: builtins.str
    description: builtins.str
    user_role: Global___Role.ValueType
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        user_role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "place_id", b"place_id", "user_role", b"user_role"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___PlaceSummary: typing_extensions.TypeAlias = PlaceSummary

@typing.final
class UpdatePlaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    name: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "name", b"name", "place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdatePlaceRequest: typing_extensions.TypeAlias = UpdatePlaceRequest

@typing.final
class UpdatePlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACE_ID_FIELD_NUMBER: builtins.int
    place_id: builtins.str
    def __init__(
        self,
        *,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdatePlaceResponse: typing_extensions.TypeAlias = UpdatePlaceResponse

@typing.final
class DeletePlaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeletePlaceRequest: typing_extensions.TypeAlias = DeletePlaceRequest

@typing.final
class DeletePlaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DeletePlaceResponse: typing_extensions.TypeAlias = DeletePlaceResponse

@typing.final
class AddMemberRequest(google.protobuf.message.Message):
    """--- Members ---"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    target_user_id: builtins.str
    role: Global___Role.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        target_user_id: builtins.str = ...,
        role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "role", b"role", "target_user_id", b"target_user_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AddMemberRequest: typing_extensions.TypeAlias = AddMemberRequest

@typing.final
class AddMemberResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___AddMemberResponse: typing_extensions.TypeAlias = AddMemberResponse

@typing.final
class RemoveMemberRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    target_user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        target_user_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "target_user_id", b"target_user_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RemoveMemberRequest: typing_extensions.TypeAlias = RemoveMemberRequest

@typing.final
class RemoveMemberResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RemoveMemberResponse: typing_extensions.TypeAlias = RemoveMemberResponse

@typing.final
class UpdateMemberRoleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    target_user_id: builtins.str
    role: Global___Role.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
        target_user_id: builtins.str = ...,
        role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "role", b"role", "target_user_id", b"target_user_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateMemberRoleRequest: typing_extensions.TypeAlias = UpdateMemberRoleRequest

@typing.final
class UpdateMemberRoleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateMemberRoleResponse: typing_extensions.TypeAlias = UpdateMemberRoleResponse

@typing.final
class ListMembersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PLACE_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    place_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        place_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["place_id", b"place_id", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListMembersRequest: typing_extensions.TypeAlias = ListMembersRequest

@typing.final
class ListMembersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBERS_FIELD_NUMBER: builtins.int
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___MemberInfo]: ...
    def __init__(
        self,
        *,
        members: collections.abc.Iterable[Global___MemberInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["members", b"members"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListMembersResponse: typing_extensions.TypeAlias = ListMembersResponse

@typing.final
class MemberInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    role: Global___Role.ValueType
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        role: Global___Role.ValueType = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["role", b"role", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MemberInfo: typing_extensions.TypeAlias = MemberInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x04\x61uth\"D\n\x0fRegisterRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"#\n\x10RegisterResponse\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"<\n\rLoginResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"-\n\x14RefreshTokensRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"D\n\x15RefreshTokensResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"&\n\rLogoutRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"!\n\x0eLogoutResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x1f\n\x0cGetMeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"V\n\rGetMeResponse\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x13\n\x0bis_verified\x18\x04 \x01(\x08\"&\n\x15GetUserByEmailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"J\n\x16GetUserByEmailResponse\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\",\n\x14ValidateTokenRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"X\n\x15ValidateTokenResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"\x1f\n\x0eSendOtpRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\"\n\x0fSendOtpResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"/\n\x10VerifyOtpRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"$\n\x11VerifyOtpResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xb8\x04\n\x0b\x41uthService\x12\x39\n\x08Register\x12\x15.auth.RegisterRequest\x1a\x16.auth.RegisterResponse\x12\x30\n\x05Login\x12\x12.auth.LoginRequest\x1a\x13.auth.LoginResponse\x12H\n\rRefreshTokens\x12\x1a.auth.RefreshTokensRequest\x1a\x1b.auth.RefreshTokensResponse\x12\x33\n\x06Logout\x12\x13.auth.LogoutRequest\x1a\x14.auth.LogoutResponse\x12\x30\n\x05GetMe\x12\x12.auth.GetMeRequest\x1a\x13.auth.GetMeResponse\x12K\n\x0eGetUserByEmail\x12\x1b.auth.GetUserByEmailRequest\x1a\x1c.auth.GetUserByEmailResponse\x12H\n\rValidateToken\x12\x1a.auth.ValidateTokenRequest\x1a\x1b.auth.ValidateTokenResponse\x12\x36\n\x07SendOtp\x12\x14.auth.SendOtpRequest\x1a\x15.auth.SendOtpResponse\x12<\n\tVerifyOtp\x12\x16.auth.VerifyOtpRequest\x1a\x17.auth.VerifyOtpResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REGISTERREQUEST']._serialized_start=20
  _globals['_REGISTERREQUEST']._serialized_end=88
  _globals['_REGISTERRESPONSE']._serialized_start=90
  _globals['_REGISTERRESPONSE']._serialized_end=125
  _globals['_LOGINREQUEST']._serialized_start=127
  _globals['_LOGINREQUEST']._serialized_end=174
  _globals['_LOGINRESPONSE']._serialized_start=176
  _globals['_LOGINRESPONSE']._serialized_end=236
  _globals['_REFRESHTOKENSREQUEST']._serialized_start=238
  _globals['_REFRESHTOKENSREQUEST']._serialized_end=283
  _globals['_REFRESHTOKENSRESPONSE']._serialized_start=285
  _globals['_REFRESHTOKENSRESPONSE']._serialized_end=353
  _globals['_LOGOUTREQUEST']._serialized_start=355
  _globals['_LOGOUTREQUEST']._serialized_end=393
  _globals['_LOGOUTRESPONSE']._serialized_start=395
  _globals['_LOGOUTRESPONSE']._serialized_end=428
  _globals['_GETMEREQUEST']._serialized_start=430
  _globals['_GETMEREQUEST']._serialized_end=461
  _globals['_GETMERESPONSE']._serialized_start=463
  _globals['_GETMERESPONSE']._serialized_end=549
  _globals['_GETUSERBYEMAILREQUEST']._serialized_start=551
  _globals['_GETUSERBYEMAILREQUEST']._serialized_end=589
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_start=591
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_end=665
  _globals['_VALIDATETOKENREQUEST']._serialized_start=667
  _globals['_VALIDATETOKENREQUEST']._serialized_end=711
  _globals['_VALIDATETOKENRESPONSE']._serialized_start=713
  _globals['_VALIDATETOKENRESPONSE']._serialized_end=801
  _globals['_SENDOTPREQUEST']._serialized_start=803
  _globals['_SENDOTPREQUEST']._serialized_end=834
  _globals['_SENDOTPRESPONSE']._serialized_start=836
  _globals['_SENDOTPRESPONSE']._serialized_end=870
  _globals['_VERIFYOTPREQUEST']._serialized_start=872
  _globals['_VERIFYOTPREQUEST']._serialized_end=919
  _globals['_VERIFYOTPRESPONSE']._serialized_start=921
  _globals['_VERIFYOTPRESPONSE']._serialized_end=957
  _globals['_AUTHSERVICE']._serialized_start=960
  _globals['_AUTHSERVICE']._serialized_end=1528
# @@protoc_insertion_point(module_scope)
